@@ -53,5 +53,5 @@ pub fn read_from_file(file: &str) -> Result<Config, Box<dyn std::error::Error>>
     info!("Reading config from {}.", file);
     let config_file = fs::read_to_string(file);
     let config: Config = toml::from_str(&config_file?)?;
-    return Ok(config);
+    Ok(config)
 }
